@@ -8,6 +8,7 @@ from bfit import logger_name
 from bdata import bdata, bmerged
 from functools import partial
 from bfit.backend.fitdata import fitdata
+from bfit.gui.popup_prepare_data import popup_prepare_data
 from bfit.backend.entry_color_set import on_focusout, on_entry_click
 import bfit.backend.colors as colors
 import numpy as np
@@ -26,6 +27,7 @@ class fetch_files(object):
             
             asym_type: StringVar, drawing style
             bfit: pointer to parent class
+            base_bins = IntVar, number of bins to use as baseline on scan ends
             canvas_frame_id: id number of frame in canvas
             check_rebin: IntVar for handling rebin aspect of checkall
             check_bin_remove: StringVar for handing omission of 1F data
@@ -43,6 +45,7 @@ class fetch_files(object):
             fet_entry_frame: frame of fetch tab
             listbox_history: listbox for run input history
             max_number_fetched: max number of files you can fetch
+            omit_state: BooleanVar, if true set omit all final incomplete scans
             run: StringVar input to fetch runs.
             runmode_label: display run mode
             runmode: display run mode list of strings
@@ -152,32 +155,63 @@ class fetch_files(object):
         
         # Frame for group set options ----------------------------------------
         right_frame = ttk.Labelframe(bigright_frame, \
-                text='Operations on Checked Items', pad=30)
+                text='Operations on Active Items', pad=30)
         
         check_remove = ttk.Button(right_frame, text='Remove', \
                 command=self.remove_all, pad=5)
         check_draw = ttk.Button(right_frame, text='Draw', \
                 command=lambda:self.draw_all('data'), pad=5)
         
-        check_rebin_label = ttk.Label(right_frame, text="Rebin:", pad=5)
-        check_rebin_box = Spinbox(right_frame, from_=1, to=100, width=3, \
+        
+        # Scan repair options ------------------------------------------------
+        frame_scan = ttk.Labelframe(right_frame, \
+                text='Scan Repair Options', pad=5)
+        
+        check_rebin_label = ttk.Label(frame_scan, text="Rebin:", pad=5)
+        check_rebin_box = Spinbox(frame_scan, from_=1, to=100, width=3, \
                 textvariable=self.check_rebin, 
-                command=self.set_all)
-        check_bin_remove_entry = Entry(right_frame, \
+                command=lambda: self.set_all('rebin'))
+        
+        check_bin_remove_label = ttk.Label(frame_scan, text="Remove:", pad=5)
+        check_bin_remove_entry = Entry(frame_scan, \
                 textvariable=self.check_bin_remove, width=20)
         
+        self.omit_state = BooleanVar()
+        omit_checkbox = ttk.Checkbutton(frame_scan, 
+                text='Omit incomplete final scan', variable=self.omit_state, 
+                onvalue=True, offvalue=False, pad=5, 
+                command=lambda: self.set_all('omit_scan'))
+        self.omit_state.set(False)
+        
+        self.base_bins = IntVar()
+        base_label = ttk.Label(frame_scan, text="baseline bins", pad=5)
+        base_spinbox = Spinbox(frame_scan, from_=0, to=1000, width=4, \
+                               textvariable=self.base_bins, 
+                               command=lambda: self.set_all('base_bins'))
+        self.base_bins.set(0)
+        
+        # grid
+        check_rebin_label.grid(     column=0, row=0, sticky='e')
+        check_rebin_box.grid(       column=1, row=0, sticky='w')
+        check_bin_remove_label.grid(column=0, row=1, sticky='e')
+        check_bin_remove_entry.grid(column=1, row=1, sticky='w', columnspan=2)
+        omit_checkbox.grid(column=0, row=2, sticky='w', columnspan=2)
+        base_spinbox.grid(column=0, row=3, sticky='e')
+        base_label.grid(column=1, row=3, sticky='w')
+        
         # key bindings
-        check_bin_remove_entry.bind('<KeyRelease>', self.set_all)
-        check_rebin_box.bind('<KeyRelease>', self.set_all)
+        check_bin_remove_entry.bind('<KeyRelease>', lambda x: self.set_all('omit'))
+        check_rebin_box.bind('<KeyRelease>', lambda x: self.set_all('rebin'))
+        base_spinbox.bind('<KeyRelease>', lambda x: self.set_all('base_bins'))
         
+        # checkboxes
+        right_checkbox_frame = ttk.Frame(right_frame)
         
-        check_all_box = ttk.Checkbutton(right_frame, 
-                text='Force Check State', variable=self.check_state, 
+        check_all_box = ttk.Checkbutton(right_checkbox_frame, 
+                text='State', variable=self.check_state, 
                 onvalue=True, offvalue=False, pad=5, command=self.check_all)
         self.check_state.set(True)
         
-        right_checkbox_frame = ttk.Frame(right_frame)
-        
         self.check_state_data = BooleanVar()        
         check_data_box = ttk.Checkbutton(right_checkbox_frame, 
                 text='Data', variable=self.check_state_data, 
@@ -221,25 +255,20 @@ class fetch_files(object):
         self.data_canvas.grid(column=0, row=1, sticky=(E, W, S, N), padx=5, pady=5)
         yscrollbar.grid(column=1, row=1, sticky=(W, S, N), pady=5)
         
-        check_data_box.grid(        column=0, row=0, sticky=(N))
-        check_fit_box.grid(         column=1, row=0, sticky=(N))
-        check_res_box.grid(         column=2, row=0, sticky=(N)) 
+        check_all_box.grid(        column=0, row=0, sticky=(N))
+        check_data_box.grid(        column=1, row=0, sticky=(N))
+        check_fit_box.grid(         column=2, row=0, sticky=(N))
+        check_res_box.grid(         column=3, row=0, sticky=(N)) 
         
         right_frame.grid(           column=0, row=0, sticky=(N, E, W))
         r = 0
-        check_all_box.grid(         column=0, row=r, sticky=(N), columnspan=2); r+= 1
         right_checkbox_frame.grid(  column=0, row=r, sticky=(N), columnspan=2); r+= 1
         check_toggle_button.grid(   column=0, row=r, sticky=(N, E, W), columnspan=2, pady=1, padx=5); r+= 1
         check_draw.grid(            column=0, row=r, sticky=(N, W, E), pady=5, padx=5);
         check_remove.grid(          column=1, row=r, sticky=(N, E, W), pady=5, padx=5); r+= 1
-        check_rebin_label.grid(     column=0, row=r)
-        check_rebin_box.grid(       column=1, row=r); r+= 1
-        check_bin_remove_entry.grid(column=0, row=r, sticky=(N), columnspan=2); r+= 1
+        frame_scan.grid(            column=0, row=r, sticky=(N, E, W), pady=5, padx=5, columnspan=2); r+= 1        
         bigright_frame.grid(        rowspan=2, sticky=(N, E, W))
         
-        check_rebin_box.grid_configure(padx=5, pady=5, sticky=(E, W))
-        check_rebin_label.grid_configure(padx=5, pady=5, sticky=(E, W))
-        
         # resizing
         fetch_data_tab.grid_columnconfigure(0, weight=1)        # main area
         fetch_data_tab.grid_rowconfigure(1, weight=1)            # main area
@@ -717,35 +746,43 @@ class fetch_files(object):
             pass
 
     # ======================================================================= #
-    def set_all(self, *args):
+    def set_all(self, changed, *args):
         """Set a particular property for all checked items. """
         
         self.logger.info('Set all')
+        data = self.bfit.data
         
         # check all file lines
-        for r in self.data_lines.keys():
+        for dat in data.values():
             
             # if checked
-            if self.data_lines[r].check_state.get():
+            if dat.check_state.get():
                 
-                # get values to enter
-                try:
-                    rebin = self.check_rebin.get()
-                except TclError:
-                    rebin = 1
-                    
-                self.data_lines[r].rebin.set(rebin)
-                new_text = self.check_bin_remove.get()
+                # rebin
+                if changed == 'rebin':
+                    try:
+                        rebin = self.check_rebin.get()
+                    except TclError:
+                        rebin = 1
+                        
+                    dat.rebin.set(rebin)
                 
-                # check for greyed text
-                if new_text != self.bin_remove_starter_line:
-                    self.data_lines[r].bin_remove.set(new_text)
-                else:
-                    self.data_lines[r].bin_remove.set("")
+                # omit bins
+                elif changed == 'omit':
+                    dat.omit.set(self.check_bin_remove.get())
+                
+                # omit scan
+                elif changed == 'omit_scan':
+                    dat.omit_scan.set(self.omit_state.get())
+                
+                # baseline corrections
+                elif changed == 'base_bins':
+                    try:
+                        val = self.base_bins.get()
+                    except TclError:
+                        val = 1
+                    dat.base_bins.set(val)
                     
-                # generate focus out event: trigger grey text reset
-                self.data_lines[r].bin_remove_entry.event_generate('<FocusOut>')
-
     # ======================================================================= #
     def set_all_labels(self):
         """Set lable text in all items """
@@ -869,7 +906,6 @@ class dataline(object):
         bdfit:          fitdata object 
         bfit:           pointer to root 
         bin_remove:     StringVar for specifying which bins to remove in 1f runs
-        bin_remove_entry: Entry object for bin remove 
         check:          Checkbox for selection (related to check_state)
         check_data:     BooleanVar for specifying to draw data
         check_fit:      BooleanVar for specifying to draw fit
@@ -904,9 +940,15 @@ class dataline(object):
         # get logger
         self.logger = logging.getLogger(logger_name)
         self.logger.debug('Initializing run %d (%d)', bdfit.run, bdfit.year)
-        
+    
         # variables
         self.bfit = bfit
+        self.row = row
+        
+        # variables from fitdata object
+        self.bdfit = bdfit
+        bd = bdfit.bd
+        
         self.bin_remove = bdfit.omit
         self.label = bdfit.label
         self.rebin = bdfit.rebin
@@ -914,22 +956,20 @@ class dataline(object):
         self.mode = bdfit.mode
         self.run =  bdfit.run
         self.year = bdfit.year
-        self.row = row
         self.lines_list = lines_list
         self.lines_list_old = lines_list_old
-        bd = bdfit.bd
-        self.bdfit = bdfit
         self.id = bdfit.id
         self.bdfit.dataline = self
         
+        self.check_data = bdfit.check_draw_data
+        self.check_fit = bdfit.check_draw_fit
+        self.check_res = bdfit.check_draw_res
+        
         # build objects
         line_frame = Frame(fetch_tab_frame)
         line_frame.bind('<Enter>', self.on_line_enter)
         line_frame.bind('<Leave>', self.on_line_leave)
         
-        bin_remove_entry = Entry(line_frame, textvariable=self.bin_remove, \
-                width=17)
-                
         label_label = ttk.Label(line_frame, text="Label:", pad=5)
         self.label_entry = Entry(line_frame, textvariable=self.label, \
                 width=18)
@@ -940,20 +980,14 @@ class dataline(object):
                                  command=lambda:self.draw(figstyle='data'), 
                                  pad=1)
         
-        self.check_data = BooleanVar()
-        self.check_data.set(True)
         draw_data_checkbox = ttk.Checkbutton(line_frame, text='Data', 
                 variable=self.check_data, onvalue=True, offvalue=False, pad=5, 
                 command=self.do_check_data)
         
-        self.check_fit = BooleanVar()
-        self.check_fit.set(False)
         self.draw_fit_checkbox = ttk.Checkbutton(line_frame, text='Fit', 
                 variable=self.check_fit, onvalue=True, offvalue=False, pad=5, 
                 state=DISABLED, command=self.do_check_fit)
         
-        self.check_res = BooleanVar()
-        self.check_res.set(False)
         self.draw_res_checkbox = ttk.Checkbutton(line_frame, text='Res', 
                 variable=self.check_res, onvalue=True, offvalue=False, pad=5, 
                 state=DISABLED, command=self.do_check_res)
@@ -968,25 +1002,19 @@ class dataline(object):
                 onvalue=True, offvalue=False, pad=5)
          
         self.set_check_text()
+        
+        # add button for data prep
+        button_prep_data = ttk.Button(line_frame, text='Prep Data', 
+                                      command=lambda : popup_prepare_data(self.bfit, self.bdfit), 
+                                      pad=1)
          
-        # add grey text to bin removal
-        bin_remove_entry.insert(0, self.bin_remove_starter_line)
-        entry_fn = partial(on_entry_click, \
-                text=self.bin_remove_starter_line, entry=bin_remove_entry)
-        on_focusout_fn = partial(on_focusout, \
-                text=self.bin_remove_starter_line, entry=bin_remove_entry)
-        bin_remove_entry.bind('<FocusIn>', entry_fn)
-        bin_remove_entry.bind('<FocusOut>', on_focusout_fn)
-        bin_remove_entry.config(foreground=colors.entry_grey)
-             
         # add grey text to label
         self.set_label()
                 
         # grid
         c = 1
         self.check.grid(column=c, row=0, sticky=E); c+=1
-        if self.mode in ['1f', '1n', '1w', '1x']: 
-            bin_remove_entry.grid(column=c, row=0, sticky=E); c+=1
+        button_prep_data.grid(column=c, row=0, sticky=E); c+=1
         rebin_label.grid(column=c, row=0, sticky=E); c+=1
         rebin_box.grid(column=c, row=0, sticky=E); c+=1
         label_label.grid(column=c, row=0, sticky=E); c+=1
@@ -1006,8 +1034,7 @@ class dataline(object):
         
         # passing
         self.line_frame = line_frame
-        self.bin_remove_entry = bin_remove_entry
-        
+                
     # ======================================================================= #
     def __del__(self):
         
